Documentation
¶
Overview ¶
Package problem helps deliver actionable feedback to a user based on an error message.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Problem ¶
type Problem struct {
// ID is an arbitrary unique and stable string describing this issue
ID string
// Err is the original error
Err error
// Advice is actionable text that the user should follow
Advice string
// URL is a reference URL for more information
URL string
// Issues are a list of related issues to this problem
Issues []int
// Hide the new issue link: it isn't our problem, and we won't be able to suggest additional assistance.
ShowIssueLink bool
}
Problem represents a known problem in minikube.
Click to show internal directories.
Click to hide internal directories.