Documentation
¶
Index ¶
Constants ¶
const ( // Podman is Kubernetes in container using podman driver Podman = "podman" // Docker is Kubernetes in container using docker driver Docker = "docker" // Mock driver Mock = "mock" // None driver None = "none" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Configurator ¶ added in v1.5.0
type Configurator func(config.ClusterConfig, config.Node) (interface{}, error)
Configurator emits a struct to be marshalled into JSON for Machine Driver
type DriverDef ¶
type DriverDef struct {
// Name of the machine driver. It has to be unique.
Name string
// Alias contains a list of machine driver aliases. Each alias should also be unique.
Alias []string
// Config is a function that emits a configured driver struct
Config Configurator
// Init is a function that initializes a machine driver, if built-in to the minikube binary
Init Loader
// Status returns the installation status of the driver
Status StatusChecker
// Default is whether this driver is selected by default or not (opt-in).
Default bool
// Priority returns the prioritization for selecting a driver by default.
Priority Priority
}
DriverDef defines how to initialize and load a machine driver
type DriverState ¶ added in v1.5.0
type DriverState struct {
// Name is the name of the driver used internally
Name string
// Default drivers are selected automatically
Default bool
// Preference is the original priority from driver
Preference Priority
// Priority is the effective priority with health
Priority Priority
// State is the state of driver and dependencies
State State
// Rejection is why we chose not to use this driver
Rejection string
// Suggestion is how the user could improve health
Suggestion string
}
DriverState is metadata relating to a driver and status
func Available ¶ added in v1.6.0
func Available(vm bool) []DriverState
Available returns a list of available drivers in the global registry
func (DriverState) String ¶ added in v1.5.0
func (d DriverState) String() string
type Priority ¶ added in v1.5.0
type Priority int
Priority is how we determine what driver to default to
const ( // Unknown is when there is no status check available Unknown Priority = iota // Obsolete is when a driver has been removed Obsolete // Unhealthy is when a driver does not pass health checks Unhealthy // Experimental is when a driver is not officially supported because it's still experimental Experimental // Discouraged is when a driver has caveats that preclude it's recommendation Discouraged // Deprecated is when a driver has been formally deprecated Deprecated // Fallback is when a driver works well, but may not be high performance Fallback // Default is what most 3rd party drivers are Default // Preferred is for drivers that use a native hypervisor interface Preferred // HighlyPreferred is the ultimate driver preferences HighlyPreferred )
type Registry ¶
type Registry interface {
// Register a driver in registry
Register(driver DriverDef) error
// Driver returns the registered driver from a given name
Driver(name string) (DriverDef, error)
// List
List() []DriverDef
}
Registry contains all the supported driver definitions on the host
type State ¶ added in v1.5.0
type State struct {
Installed bool
Healthy bool
Running bool // it at least appears to be running
NeedsImprovement bool // healthy but could be improved
Error error
Reason string // A reason ID, propagated to reason.Kind.ID
Fix string
Doc string
Version string // Provider version
}
State is the current state of the driver and its dependencies
type StatusChecker ¶ added in v1.5.0
type StatusChecker func() State
StatusChecker checks if a driver is available, offering a
Click to show internal directories.
Click to hide internal directories.